/*
Programs for a binary outcome representing a time-dependent event (with log-hazards regression)
and a time-independent classification (with logistic regression) using the same simulated data.
There is no repeated measurement in the dataset, hence no random or repeated statements.
*/
*Import the data using the following code or find and double-click binary outcome odds or hazards data.xlsx in SAS Studio;

FILENAME REFFILE '/folders/myshortcuts/ExternalFiles/Projects/Mixed-model Workshop/Generalized linear models/binary outcome odds or hazards data.xlsx';

PROC IMPORT DATAFILE=REFFILE
	DBMS=XLSX replace
	OUT=WORK.IMPORT;
	GETNAMES=YES;
RUN;

*proc print;run;

data bindata;
set import;
BaseTrainStd=BaselineTraining;
LnMonitorWeeks=log(MonitorWeeks);

proc standard data=bindata out=bindata1 mean=0 std=0.5;
var BaseTrainStd;
run;

ods noproctitle;
ods graphics / imagemap=on;

title "Log-hazard regression, no repeated measurement";
proc glimmix data=bindata1;
class GroupID;
model DepVar=GroupID GroupID*BaseTrainStd/link=cloglog dist=binomial offset=LnMonitorWeeks;
estimate "Overall mean" int 1 GroupID 0.5 0.5 /cl exp alpha=0.1;
estimate "";
estimate "Control mean" int 1 GroupID 1 0/cl exp alpha=0.1;
estimate "Exptal mean " int 1 GroupID 0 1/cl exp alpha=0.1;
estimate "Exptal/Control mean" GroupID -1 1/cl exp alpha=0.1;
estimate "";
estimate "Control mean @ -1SD BaseTrain" int 1 GroupID 1 0 GroupID*BaseTrainStd -0.5 0/cl exp alpha=0.1;
estimate "Control mean @ +1SD BaseTrain" int 1 GroupID 1 0 GroupID*BaseTrainStd 0.5 0/cl exp alpha=0.1;
estimate "Control +1SD/-1SD BaseTrain" GroupID*BaseTrainStd 1 0/cl exp alpha=0.1;
estimate "";
estimate "Exptal mean @ -1SD BaseTrain" int 1 GroupID 0 1 GroupID*BaseTrainStd 0 -0.5/cl exp alpha=0.1;
estimate "Exptal mean @ +1SD BaseTrain" int 1 GroupID 0 1 GroupID*BaseTrainStd 0 0.5/cl exp alpha=0.1;
estimate "Exptal +1SD/-1SD BaseTrain" GroupID*BaseTrainStd 0 1/cl exp alpha=0.1;
estimate ":";
estimate "Exptal/Control mean BaseTrain reference" int 1 GroupID 0.5 0.5 
  GroupID*BaseTrainStd -0.5 -0.5/cl exp alpha=0.1;
estimate "blank";
estimate "Exptal/Control +1SD/-1SD BaseTrain" GroupID*BaseTrainStd -1 1/cl exp alpha=0.1;
lsmeans GroupID/diff cl alpha=0.1;
run;


title "Logistic regression, no repeated measurement";
proc glimmix data=bindata1;
class GroupID;
model DepVar=GroupID GroupID*BaseTrainStd/link=logit	 dist=binomial;
estimate "Overall mean" int 1 GroupID 0.5 0.5 /cl exp alpha=0.1;
estimate "";
estimate "Control mean" int 1 GroupID 1 0/cl exp alpha=0.1;
estimate "Exptal mean" int 1 GroupID 0 1/cl exp alpha=0.1;
estimate "Exptal/Control mean" GroupID -1 1/cl exp alpha=0.1;
estimate "";
estimate "Control mean @ -1SD BaseTrain" int 1 GroupID 1 0 GroupID*BaseTrainStd -0.5 0/cl exp alpha=0.1;
estimate "Control mean @ +1SD BaseTrain" int 1 GroupID 1 0 GroupID*BaseTrainStd 0.5 0/cl exp alpha=0.1;
estimate "Control +1SD/-1SD BaseTrain" GroupID*BaseTrainStd 1 0/cl exp alpha=0.1;
estimate "";
estimate "Exptal mean @ -1SD BaseTrain" int 1 GroupID 0 1 GroupID*BaseTrainStd 0 -0.5/cl exp alpha=0.1;
estimate "Exptal mean @ +1SD BaseTrain" int 1 GroupID 0 1 GroupID*BaseTrainStd 0 0.5/cl exp alpha=0.1;
estimate "Exptal +1SD/-1SD BaseTrain" GroupID*BaseTrainStd 0 1/cl exp alpha=0.1;
estimate "";
estimate "Exptal/Control mean BaseTrain reference" int 1 GroupID 0.5 0.5 
  GroupID*BaseTrainStd -0.5 -0.5/cl exp alpha=0.1;
estimate "blank";
estimate "Exptal/Control +1SD/-1SD BaseTrain" GroupID*BaseTrainStd -1 1/cl exp alpha=0.1;
lsmeans GroupID/diff cl alpha=0.1;
run;


